RegistryEventString

Trait RegistryEventString 

pub trait RegistryEventString {
    const REGISTRY_EVENT_STRING: &'static str;
}
A static Registry event string for registering with the RegistryProxy for receiving events.

Required Associated Constants

const REGISTRY_EVENT_STRING: &'static str

A registry event string for registering for event receiving via the RegistryProxy. This should be deprecated in favour of composing the string from DBusMember::DBUS_MEMBER and DBusInterface::DBUS_INTERFACE.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl RegistryEventString for CacheEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "Cache"

Source

impl RegistryEventString for DocumentEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "Document:"

Source

impl RegistryEventString for EventListenerEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "Event"

Source

impl RegistryEventString for FocusEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "focus:"

Source

impl RegistryEventString for KeyboardEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "keyboard:"

Source

impl RegistryEventString for MouseEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "mouse:"

Source

impl RegistryEventString for ObjectEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "object:"

Source

impl RegistryEventString for TerminalEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:"

Source

impl RegistryEventString for WindowEvents

Source

const REGISTRY_EVENT_STRING: &'static str = "window:"

Source

impl RegistryEventString for AddAccessibleEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "cache:add"

Source

impl RegistryEventString for LegacyAddAccessibleEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "cache:add"

Source

impl RegistryEventString for RemoveAccessibleEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "cache:remove"

Source

impl RegistryEventString for atspi_common::events::document::AttributesChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:attributes-changed"

Source

impl RegistryEventString for ContentChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:content-changed"

Source

impl RegistryEventString for LoadCompleteEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:load-complete"

Source

impl RegistryEventString for LoadStoppedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:load-stopped"

Source

impl RegistryEventString for PageChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:page-changed"

Source

impl RegistryEventString for ReloadEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "document:reload"

Source

impl RegistryEventString for FocusEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "focus:"

Source

impl RegistryEventString for ModifiersEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "keyboard:modifiers"

Source

impl RegistryEventString for AbsEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "mouse:abs"

Source

impl RegistryEventString for ButtonEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "mouse:button"

Source

impl RegistryEventString for RelEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "mouse:rel"

Source

impl RegistryEventString for ActiveDescendantChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:active-descendant-changed"

Source

impl RegistryEventString for AnnouncementEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:announcement"

Source

impl RegistryEventString for atspi_common::events::object::AttributesChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:attributes-changed"

Source

impl RegistryEventString for BoundsChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:bounds-changed"

Source

impl RegistryEventString for ChildrenChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:children-changed"

Source

impl RegistryEventString for ColumnDeletedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:column-deleted"

Source

impl RegistryEventString for ColumnInsertedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:column-inserted"

Source

impl RegistryEventString for ColumnReorderedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:column-reordered"

Source

impl RegistryEventString for LinkSelectedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:link-selected"

Source

impl RegistryEventString for ModelChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:model-changed"

Source

impl RegistryEventString for atspi_common::events::object::PropertyChangeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:property-change"

Source

impl RegistryEventString for RowDeletedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:row-deleted"

Source

impl RegistryEventString for RowInsertedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:row-inserted"

Source

impl RegistryEventString for RowReorderedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:row-reordered"

Source

impl RegistryEventString for SelectionChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:selection-changed"

Source

impl RegistryEventString for StateChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:state-changed"

Source

impl RegistryEventString for TextAttributesChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:text-attributes-changed"

Source

impl RegistryEventString for TextBoundsChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:text-bounds-changed"

Source

impl RegistryEventString for TextCaretMovedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:text-caret-moved"

Source

impl RegistryEventString for TextChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:text-changed"

Source

impl RegistryEventString for TextSelectionChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:text-selection-changed"

Source

impl RegistryEventString for VisibleDataChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "object:visible-data-changed"

Source

impl RegistryEventString for AvailableEvent

Source

const REGISTRY_EVENT_STRING: &'static str = ""

Source

impl RegistryEventString for EventListenerDeregisteredEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "registry:event-listener-deregistered"

Source

impl RegistryEventString for EventListenerRegisteredEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "registry:event-listener-registered"

Source

impl RegistryEventString for ApplicationChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:application-changed"

Source

impl RegistryEventString for CharWidthChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:char-width-changed"

Source

impl RegistryEventString for ColumnCountChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:columncount-changed"

Source

impl RegistryEventString for LineChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:line-changed"

Source

impl RegistryEventString for LineCountChangedEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "terminal:linecount-changed"

Source

impl RegistryEventString for ActivateEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:activate"

Source

impl RegistryEventString for CloseEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:close"

Source

impl RegistryEventString for CreateEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:create"

Source

impl RegistryEventString for DeactivateEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:deactivate"

Source

impl RegistryEventString for DesktopCreateEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:desktop-create"

Source

impl RegistryEventString for DesktopDestroyEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:desktop-destroy"

Source

impl RegistryEventString for DestroyEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:destroy"

Source

impl RegistryEventString for LowerEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:lower"

Source

impl RegistryEventString for MaximizeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:maximize"

Source

impl RegistryEventString for MinimizeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:minimize"

Source

impl RegistryEventString for MoveEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:move"

Source

impl RegistryEventString for atspi_common::events::window::PropertyChangeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:property-change"

Source

impl RegistryEventString for RaiseEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:raise"

Source

impl RegistryEventString for ReparentEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:reparent"

Source

impl RegistryEventString for ResizeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:resize"

Source

impl RegistryEventString for RestoreEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:restore"

Source

impl RegistryEventString for RestyleEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:restyle"

Source

impl RegistryEventString for ShadeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:shade"

Source

impl RegistryEventString for UUshadeEvent

Source

const REGISTRY_EVENT_STRING: &'static str = "window:uushade"